@@ -94,7 +94,8 @@ enum class property_types : std::uint8_t
     target_vertical_alignment,
     target_upright,
     target_direction,
-    target_font_feature_settings
+    target_font_feature_settings,
+    target_line_pattern,
 };
 
 template <typename T>
@@ -189,6 +190,7 @@ ENUM_FROM_STRING( text_transform_enum )
 ENUM_FROM_STRING( text_upright_enum )
 ENUM_FROM_STRING( direction_enum )
 ENUM_FROM_STRING( gamma_method_enum )
+ENUM_FROM_STRING( line_pattern_enum )
 
 // enum
 template <typename T, bool is_enum = true>
